@@ -53,9 +53,14 @@ class DAQPump(Pump):
         blob[data_type] = None
 
         if data_type == 'DAQSummaryslice':
-            daq_frame = DAQSummarySlice(blob_file)
+            daq_frame = DAQSummaryslice(blob_file)
+            blob[data_type] = daq_frame
+        elif data_type == 'DAQEvent':
+            daq_frame = DAQEvent(blob_file)
             blob[data_type] = daq_frame
         else:
+            log.warning("Skipping DAQ frame with data type code '{0}'."
+                        .format(preamble.data_type))
             blob_file.seek(preamble.length - DAQPreamble.size, 1)
 
         return blob
@@ -76,8 +81,7 @@ class DAQPump(Pump):
 
     def process(self, blob):
         """Pump the next blob to the modules"""
-        print(self.next_frame())
-        return blob
+        return self.next_frame()
 
     def finish(self):
         """Clean everything up"""
@@ -168,7 +172,7 @@ class DAQHeader(object):
 
 
 
-class DAQSummarySlice(object):
+class DAQSummaryslice(object):
     """Wrapper for the JDAQSummarySlice binary format.
 
     Args:
@@ -191,9 +195,8 @@ class DAQSummarySlice(object):
     def _parse_summary_frames(self, file_obj):
         """Iterate through the byte data and fill the summary_frames"""
         for i in range(self.n_summary_frames):
-            print("frame: {0}".format(i))
             dom_id = unpack('<i', file_obj.read(4))[0]
-            pmt_rates = unpack('c'*31, file_obj.read(31))
+            pmt_rates = unpack('b'*31, file_obj.read(31))
             self.summary_frames[dom_id] = pmt_rates
 
 
@@ -238,3 +241,13 @@ class DAQEvent(object):
         for i in xrange(self.n_snapshot_hits):
             dom_id, pmt_id, tdc_time, tot = unpack('<ibib', file_obj.read(10))
             self.snapshot_hits.append((dom_id, pmt_id, tdc_time, tot))
+
+    def __str__(self):
+        #string = "{class}\n{header_line}\n"
+        string = '\n'.join((
+            self.__class__.__name__,
+            "=" * len(self.__class__.__name__),
+            " Number of triggered hits: " + str(self.n_triggered_hits),
+            " Number of snapshot hits:  " + str(self.n_snapshot_hits)
+        ))
+        return string
